@@ -12,6 +12,11 @@ MapDialog::MapDialog(QWidget *parent) :
 
 int MapDialog::exec() {
     view->setParent(ui->widget);
+    if (view->source().isEmpty()) {
+        view->setSource(QUrl("qrc:///qml/googlemaps.qml"));
+        view->setResizeMode(QDeclarativeView::SizeRootObjectToView);
+    }
+
     QDeclarativeItem *item = qobject_cast<QDeclarativeItem *>(view->rootObject());
     item->setProperty("defaultLatitude", latitude);
     item->setProperty("defaultLongitude", longitude);
@@ -21,6 +26,7 @@ int MapDialog::exec() {
 
     latitude = item->property("latitude").toDouble();
     longitude = item->property("longitude").toDouble();
+    view->setParent(parentWidget());
     return result;
 }
 
