@@ -9,6 +9,7 @@
 #include <QXmlStreamReader>
 #include <QNetworkReply>
 #include <QGeoPositionInfo>
+#include <QNetworkAccessManager>
 
 
 #include <QDeclarativeView>
@@ -64,6 +65,7 @@ private:
     QXmlStreamReader xml;
     bool valid_data;
     QString lat, lng;
+    QNetworkAccessManager *manager;
 
 };
 
